==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/GCPChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface GCPChaosSpecFluent<A extends GCPChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  public A addToDeviceNames(Integer index,String item);
  public A setToDeviceNames(Integer index,String item);
  public A addToDeviceNames(java.lang.String... items);
  public A addAllToDeviceNames(Collection<String> items);
  public A removeFromDeviceNames(java.lang.String... items);
  public A removeAllFromDeviceNames(Collection<String> items);
  public List<String> getDeviceNames();
  public String getDeviceName(Integer index);
  public String getFirstDeviceName();
  public String getLastDeviceName();
  public String getMatchingDeviceName(Predicate<String> predicate);
  public Boolean hasMatchingDeviceName(Predicate<String> predicate);
  public A withDeviceNames(List<String> deviceNames);
  public A withDeviceNames(java.lang.String... deviceNames);
  public Boolean hasDeviceNames();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getInstance();
  public A withInstance(String instance);
  public Boolean hasInstance();
  public String getProject();
  public A withProject(String project);
  public Boolean hasProject();
  public String getSecretName();
  public A withSecretName(String secretName);
  public Boolean hasSecretName();
  public String getZone();
  public A withZone(String zone);
  public Boolean hasZone();
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/GCPChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface GCPChaosSpecFluent<A extends GCPChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  public A addToDeviceNames(int index,String item);
  public A setToDeviceNames(int index,String item);
  public A addToDeviceNames(java.lang.String... items);
  public A addAllToDeviceNames(Collection<String> items);
  public A removeFromDeviceNames(java.lang.String... items);
  public A removeAllFromDeviceNames(Collection<String> items);
  public List<String> getDeviceNames();
  public String getDeviceName(int index);
  public String getFirstDeviceName();
  public String getLastDeviceName();
  public String getMatchingDeviceName(Predicate<String> predicate);
  public Boolean hasMatchingDeviceName(Predicate<String> predicate);
  public A withDeviceNames(List<String> deviceNames);
  public A withDeviceNames(java.lang.String... deviceNames);
  public Boolean hasDeviceNames();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getInstance();
  public A withInstance(String instance);
  public Boolean hasInstance();
  public String getProject();
  public A withProject(String project);
  public Boolean hasProject();
  public String getSecretName();
  public A withSecretName(String secretName);
  public Boolean hasSecretName();
  public String getZone();
  public A withZone(String zone);
  public Boolean hasZone();
  
}
